import { Database } from 'arangojs';
import { AdapterOptions, DatabaseAdapter, Query, RecordData } from 'nomatic-data';
export interface ArangoDBAdapterOptions extends AdapterOptions {
    host: string;
    port: number;
    user: string;
    password: string;
}
export declare class ArangoDBAdapter extends DatabaseAdapter {
    readonly client: Database;
    constructor(options: ArangoDBAdapterOptions);
    name: string;
    private _password;
    password: string;
    private _user;
    user: string;
    createCollection(collection: string): Promise<boolean>;
    createDatabase(database?: string): Promise<boolean>;
    decode(collection: string, data: object): RecordData;
    dropCollection(collection: string): Promise<boolean>;
    dropDatabase(database?: string): Promise<boolean>;
    encode(collection: string, data: RecordData): object;
    ensureCollectionExists(collection: string): Promise<boolean>;
    ensureDatabaseExists(database?: string): Promise<boolean>;
    findAll(collection: string, query?: Query): Promise<RecordData[]>;
    get(collection: string, id: string): Promise<RecordData>;
    getCollectionNames(database?: string): Promise<string[]>;
    getDatabaseNames(): Promise<string[]>;
    insert(collection: string, data: RecordData): Promise<RecordData>;
    insertAll(collection: string, data: RecordData[]): Promise<RecordData[]>;
    queryToAQL(collection: any, query: Query): string;
    remove(collection: string, data: string | RecordData): Promise<RecordData>;
    replace(collection: string, id: string, data: RecordData, rev?: string): Promise<RecordData>;
    truncateCollection(collection: string): Promise<boolean>;
    truncateDatabase(): Promise<boolean>;
    update(collection: string, id: string, data: RecordData): Promise<RecordData>;
    load(): Promise<boolean>;
    private handleError;
}
export default ArangoDBAdapter;
